@@ -50,7 +50,7 @@
 #include "Client.h"
 #include "async.h"
 
-#define PHP_SWOOLE_VERSION  "1.10.2"
+#define PHP_SWOOLE_VERSION  "1.10.4"
 #define PHP_SWOOLE_CHECK_CALLBACK
 #define PHP_SWOOLE_ENABLE_FASTCALL
 
@@ -319,6 +319,8 @@ PHP_FUNCTION(swoole_event_exit);
 PHP_FUNCTION(swoole_event_defer);
 PHP_FUNCTION(swoole_event_cycle);
 PHP_FUNCTION(swoole_client_select);
+PHP_FUNCTION(swoole_event_dispatch);
+PHP_FUNCTION(swoole_event_isset);
 //---------------------------------------------------------
 //                  swoole_async
 //---------------------------------------------------------
