@@ -1074,7 +1074,7 @@ static int swClient_onPackage(swConnection *conn, char *data, uint32_t length)
 {
     swClient *cli = (swClient *) conn->object;
     cli->onReceive(conn->object, data, length);
-    return cli->socket->close_wait ? SW_ERR : SW_OK;
+    return conn->close_wait ? SW_ERR : SW_OK;
 }
 
 static int swClient_onStreamRead(swReactor *reactor, swEvent *event)
@@ -1190,7 +1190,7 @@ static int swClient_onStreamRead(swReactor *reactor, swEvent *event)
     {
         if (swClient_ssl_handshake(cli) < 0)
         {
-            return cli->close(cli);
+            goto connect_fail;
         }
         if (cli->socket->ssl_state != SW_SSL_STATE_READY)
         {
