@@ -273,6 +273,11 @@ static int swServer_start_check(swServer *serv)
         swWarn("serv->max_connection is too small.");
         serv->max_connection = SwooleG.max_sockets;
     }
+    if (serv->max_connection > SW_SESSION_LIST_SIZE)
+    {
+        swWarn("serv->max_connection is exceed the SW_SESSION_LIST_SIZE[%d].", SW_SESSION_LIST_SIZE);
+        serv->max_connection = SW_SESSION_LIST_SIZE;
+    }
     swListenPort *ls;
     LL_FOREACH(serv->listen_list, ls)
     {
@@ -281,7 +286,6 @@ static int swServer_start_check(swServer *serv)
             ls->protocol.package_max_length = SW_BUFFER_MIN_SIZE;
         }
     }
-    SwooleGS->session_round = 1;
     return SW_OK;
 }
 
@@ -327,6 +331,11 @@ static int swServer_start_proxy(swServer *serv)
         }
     }
 
+    if (serv->stream_fd > 0)
+    {
+        close(serv->stream_fd);
+    }
+
     /**
      * create reactor thread
      */
@@ -373,15 +382,27 @@ static int swServer_start_proxy(swServer *serv)
         swServer_call_hook_func(serv, SW_SERVER_HOOK_MASTER_START);
     }
 
+    /**
+     * init timer
+     */
+    if (swTimer_init(1000) < 0)
+    {
+        return SW_ERR;
+    }
+    /**
+     * 1 second timer, update SwooleGS->now
+     */
+    if (SwooleG.timer.add(&SwooleG.timer, 1000, 1, serv, swServer_master_onTimer) == NULL)
+    {
+        return SW_ERR;
+    }
+
     if (serv->onStart != NULL)
     {
         serv->onStart(serv);
     }
 
-    struct timeval tmo;
-    tmo.tv_sec = 1; //for seconds timer
-    tmo.tv_usec = 0;
-    return main_reactor->wait(main_reactor, &tmo);
+    return main_reactor->wait(main_reactor, NULL);
 }
 
 void swServer_store_listen_socket(swServer *serv)
@@ -434,7 +455,6 @@ void swServer_store_listen_socket(swServer *serv)
 swString** swServer_create_worker_buffer(swServer *serv)
 {
     int i;
-    int buffer_input_size = serv->listen_list->protocol.package_max_length;
     int buffer_num;
 
     if (serv->factory_mode == SW_MODE_SINGLE || serv->factory_mode == SW_MODE_BASE)
@@ -455,7 +475,7 @@ swString** swServer_create_worker_buffer(swServer *serv)
 
     for (i = 0; i < buffer_num; i++)
     {
-        buffers[i] = swString_new(buffer_input_size);
+        buffers[i] = swString_new(SW_BUFFER_SIZE_BIG);
         if (buffers[i] == NULL)
         {
             swError("worker buffer_input init failed.");
@@ -646,12 +666,15 @@ int swServer_start(swServer *serv)
         {
             return SW_ERR;
         }
+        int _reuse_port = SwooleG.reuse_port;
+        SwooleG.reuse_port = 0;
         serv->stream_fd = swSocket_create_server(SW_SOCK_UNIX_STREAM, serv->stream_socket, 0, 2048);
         if (serv->stream_fd < 0)
         {
             return SW_ERR;
         }
         swoole_fcntl_set_option(serv->stream_fd, 1, 1);
+        SwooleG.reuse_port = _reuse_port;
     }
 
     serv->send = swServer_tcp_send;
@@ -1025,6 +1048,7 @@ int swServer_tcp_notify(swServer *serv, swConnection *conn, int event)
     notify_event.from_id = conn->from_id;
     notify_event.fd = conn->fd;
     notify_event.from_fd = conn->from_fd;
+    notify_event.len = 0;
     return serv->factory.notify(&serv->factory, &notify_event);
 }
 
@@ -1153,8 +1177,9 @@ void swServer_signal_init(swServer *serv)
     swServer_set_minfd(SwooleG.serv, SwooleG.signal_fd);
 }
 
-void swServer_master_onTimer(swServer *serv)
+void swServer_master_onTimer(swTimer *timer, swTimer_node *tnode)
 {
+    swServer *serv = (swServer *) tnode->data;
     swoole_update_time();
     if (serv->scheduler_warning && serv->warning_time < SwooleGS->now)
     {
@@ -1724,18 +1749,18 @@ static swConnection* swServer_connection_new(swServer *serv, swListenPort *ls, i
 #endif
 
 #ifdef SW_REACTOR_USE_SESSION
-    uint32_t session_id = 1;
     swSession *session;
     sw_spinlock(&SwooleGS->spinlock);
     int i;
+    uint32_t session_id = SwooleGS->session_round;
     //get session id
     for (i = 0; i < serv->max_connection; i++)
     {
-        session_id = SwooleGS->session_round++;
-        if (unlikely(session_id == 0))
+        session_id++;
+        //SwooleGS->session_round just has 24 bits size;
+        if (unlikely(session_id == 1 << 24))
         {
             session_id = 1;
-            SwooleGS->session_round = 1;
         }
         session = swServer_get_session(serv, session_id);
         //vacancy
@@ -1747,6 +1772,7 @@ static swConnection* swServer_connection_new(swServer *serv, swListenPort *ls, i
             break;
         }
     }
+    SwooleGS->session_round = session_id;
     sw_spinlock_release(&SwooleGS->spinlock);
     connection->session_id = session_id;
 #endif
