@@ -108,10 +108,6 @@
 
 #define SW_TASKWAIT_TIMEOUT        0.5
 
-#ifdef HAVE_EVENTFD
-#define HAVE_LINUX_AIO
-#endif
-
 #define SW_AIO_THREAD_NUM_DEFAULT        2
 #define SW_AIO_THREAD_NUM_MAX            32
 #define SW_AIO_MAX_FILESIZE              4194304  //4M
@@ -280,6 +276,6 @@
 
 #define SW_REDIS_CONNECT_TIMEOUT         1.0
 
-#define SW_PHP_FUNCTION_MAX_ARG          16
+#define SW_TIMER_MAX_VALUE               86400000
 
 #endif /* SWOOLE_CONFIG_H_ */
