@@ -76,6 +76,10 @@ void swoole_server_port_init(int module_number TSRMLS_DC)
     zend_declare_property_long(swoole_server_port_class_entry_ptr, ZEND_STRL("type"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
     zend_declare_property_long(swoole_server_port_class_entry_ptr, ZEND_STRL("sock"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
     zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC TSRMLS_CC);
+
+#ifdef HAVE_PCRE
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("connections"), ZEND_ACC_PUBLIC TSRMLS_CC);
+#endif
 }
 
 static PHP_METHOD(swoole_server_port, __construct)
@@ -115,6 +119,10 @@ static PHP_METHOD(swoole_server_port, set)
     {
         return;
     }
+    if (Z_TYPE_P(zset) != IS_ARRAY)
+    {
+        RETURN_FALSE;
+    }
 
     php_swoole_array_separate(zset);
     vht = Z_ARRVAL_P(zset);
